@@ -1,10 +1,6 @@
 use std::error::Error;
 use std::ffi::NulError;
-use std::fmt::{
-    self,
-    Display,
-    Formatter,
-};
+use std::fmt::{self, Display, Formatter};
 use std::io;
 
 /// Enum with all possible canvas errors that could occur.
