@@ -4,38 +4,22 @@ use std::rc::Rc;
 #[cfg(not(target_arch = "wasm32"))]
 use std::ffi::c_void;
 
+#[cfg(all(feature = "glutin", not(target_arch = "wasm32")))]
+use glutin::{window::Window, ContextWrapper, PossiblyCurrent};
+
 use fnv::FnvHashMap;
 use imgref::ImgVec;
 use rgb::RGBA8;
 
 use crate::{
-    renderer::{
-        GlyphTexture,
-        ImageId,
-        Vertex,
-    },
-    BlendFactor,
-    Color,
-    CompositeOperationState,
-    ErrorKind,
-    FillRule,
-    ImageFilter,
-    ImageInfo,
-    ImageSource,
-    ImageStore,
+    renderer::{GlyphTexture, ImageId, Vertex},
+    BlendFactor, Color, CompositeOperationState, ErrorKind, FillRule, ImageFilter, ImageInfo, ImageSource, ImageStore,
     Scissor,
 };
 
 use glow::HasContext;
 
-use super::{
-    Command,
-    CommandType,
-    Params,
-    RenderTarget,
-    Renderer,
-    ShaderType,
-};
+use super::{Command, CommandType, Params, RenderTarget, Renderer, ShaderType};
 
 mod program;
 use program::MainProgram;
@@ -66,16 +50,35 @@ pub struct OpenGl {
 
 impl OpenGl {
     #[cfg(not(target_arch = "wasm32"))]
+    #[deprecated(
+        since = "0.3",
+        note = "This function unsafe. Use OpenGl::new_from_function or OpenGl::new_from_glutin_context"
+    )]
     pub fn new<F>(load_fn: F) -> Result<Self, ErrorKind>
     where
         F: FnMut(&str) -> *const c_void,
     {
-        let context = unsafe { glow::Context::from_loader_function(load_fn) };
-        let version = unsafe { context.get_parameter_string(glow::VERSION) };
+        unsafe { Self::new_from_function(load_fn) }
+    }
+
+    #[cfg(not(target_arch = "wasm32"))]
+    pub unsafe fn new_from_function<F>(load_fn: F) -> Result<Self, ErrorKind>
+    where
+        F: FnMut(&str) -> *const c_void,
+    {
+        let context = glow::Context::from_loader_function(load_fn);
+        let version = context.get_parameter_string(glow::VERSION);
         let is_opengles_2_0 = version.starts_with("OpenGL ES 2.");
         Self::new_from_context(context, is_opengles_2_0)
     }
 
+    #[cfg(all(feature = "glutin", not(target_arch = "wasm32")))]
+    pub fn new_from_glutin_context(
+        windowed_context: &ContextWrapper<PossiblyCurrent, Window>,
+    ) -> Result<Self, ErrorKind> {
+        unsafe { OpenGl::new_from_function(|s| windowed_context.get_proc_address(s) as *const _) }
+    }
+
     #[cfg(target_arch = "wasm32")]
     pub fn new_from_html_canvas(canvas: &web_sys::HtmlCanvasElement) -> Result<Self, ErrorKind> {
         let mut attrs = web_sys::WebGlContextAttributes::new();
